<?php

declare(strict_types=1);

namespace PortalPeople\documentdesigner\services;

/**
 * OcrService
 *
 * Thin wrapper around the legacy \backend\models\data\Ocr static call.
 * Extracted from api/modules/v1/controllers/OcrController.
 */
class OcrService
{
    /**
     * Scan an uploaded file using OCR.
     *
     * @param array<string, mixed> $file  Contents of $_FILES['OcrFile'] (or equivalent)
     * @return mixed  OCR scan result as returned by Ocr::Scanfile()
     */
    public function scanFile(array $file): mixed
    {
        return \backend\models\data\Ocr::Scanfile($file);
    }
}
